# -*- coding: utf-8 -*-
#
# Copyright © 2012 - 2020 Michal Čihař <michal@cihar.com>
#
# This file is part of Weblate <https://weblate.org/>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.
#

from __future__ import unicode_literals

from weblate.memory.storage import TranslationMemory
from weblate.utils.management.base import BaseCommand


class Command(BaseCommand):
    """Command for optimizing translation memory content."""

    help = 'optimizes translation memory content'

    def add_arguments(self, parser):
        super(Command, self).add_arguments(parser)
        parser.add_argument(
            '--rebuild', help='Rebuild from scratch', action='store_true'
        )

    def optimize(self):
        memory = TranslationMemory()
        memory.index.optimize()

    def rebuild(self):
        memory = TranslationMemory()
        data = list(memory.searcher.documents())
        memory.empty()
        with memory.writer() as writer:
            for entry in data:
                writer.add_document(**entry)

    def handle(self, *args, **options):
        """Translation memory cleanup."""
        if options['rebuild']:
            self.rebuild()
        else:
            self.optimize()
